This function calculates the body surface area with the DuBois method. DuBois D. A formula to estimate the approximate surface area if height and body mass are known. Arch Intern Med 1916;17:863-71.
This function calculates the body surface area with the DuBois method. DuBois D. A formula to estimate the approximate surface area if height and body mass are known. Arch Intern Med 1916;17:863-71.